package com.isu.gaswellwatch.modbus.data.decode.impl;

import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 时间类型解析器
 * 支持解析：999:59:59, 实际使用中请不要转为LocalTime
 *
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/11/24 21:38
 */
@Component(StringTimeDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class StringTimeDecodeHandler implements DecodeHandler {
    public static final String NAME = "stringTime";

    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isBlank(value)) {
            return value;
        }
        return Arrays.stream(StringUtils.split(value, ":"))
                .map(item -> StringUtils.leftPad(item, 2, '0'))
                .collect(Collectors.joining(":"));
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, point.getValue()));
    }

}
