package com.isu.gaswellwatch.modbus.data.listener;

/**
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/11/23 0:32
 */

import org.springframework.amqp.core.AmqpAdmin;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.core.QueueBuilder;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.listener.SimpleMessageListenerContainer;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;

import java.util.stream.IntStream;


@Component
public class DynamicRabbitListener implements ApplicationRunner {

    private final AmqpAdmin amqpAdmin;
    private final ComposeModbusMessageListener composeListener;
    private final SimpleMessageListenerContainer modbusMessageListenerContainer;

    public DynamicRabbitListener(ConnectionFactory connectionFactory) {
        this.amqpAdmin = new RabbitAdmin(connectionFactory);
        this.composeListener = new ComposeModbusMessageListener();
        this.modbusMessageListenerContainer = new SimpleMessageListenerContainer();
        this.modbusMessageListenerContainer.setConnectionFactory(connectionFactory);
        this.modbusMessageListenerContainer.setMessageListener(this.composeListener);
        // 启动监听容器
        this.modbusMessageListenerContainer.start();
    }

    @Override
    public void run(ApplicationArguments args) {
//        this.composeListener.addBatchMessageListener(new ModbusMessageBackupListener());
        this.composeListener.addBatchMessageListener(new ModbusMessagePersistListener());
        IntStream.range(0, 10).forEach(index -> {
            this.addEventListener(Queues.DEVICE_EVENTS + index);
            this.addCollectDataListener(Queues.MODBUS_COLLECT_DATA + index);
        });
    }

    private void addCollectDataListener(String queueName) {
        Queue queue = QueueBuilder.durable(queueName).build();
        this.amqpAdmin.declareQueue(queue);
        this.modbusMessageListenerContainer.addQueues(queue);
    }

    private void addEventListener(String queueName) {
        this.amqpAdmin.declareQueue(QueueBuilder.durable(queueName).build());
    }

}