package com.isu.gaswellwatch.utils;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import org.apache.commons.lang3.StringUtils;
import org.springframework.core.convert.converter.Converter;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/1/26 16:04
 */
public class StringToLocalDateTimeConverter extends JsonDeserializer<LocalDateTime> implements Converter<String, LocalDateTime> {

    public static final StringToLocalDateTimeConverter INSTANCE = new StringToLocalDateTimeConverter();
    public static final DateTimeFormatter ZH_CN_LOCAL_DATE_TIME = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    @Override
    public LocalDateTime deserialize(JsonParser jsonParser, DeserializationContext context) throws IOException {
        return convert(jsonParser.getText());
    }

    @Override
    public LocalDateTime convert(String source) {
        if (StringUtils.isBlank(source)) {
            return null;
        }
        LocalDateTime localDateTime = null;
        if (source.length() == 10) {
            localDateTime = LocalDate.parse(source).atStartOfDay();
        } else {
            if (source.contains("T")) {
                localDateTime = LocalDateTime.parse(source, DateTimeFormatter.ISO_LOCAL_DATE_TIME);
            } else {
                localDateTime = LocalDateTime.parse(source, ZH_CN_LOCAL_DATE_TIME);
            }
        }
        return localDateTime;
    }

    @Override
    public Class<LocalDateTime> handledType() {
        return LocalDateTime.class;
    }
}
